import React, { useState, useEffect } from 'react';
import axios from 'axios';
import './css/form.css';
import './css/style.css';


const Dropdown = ({ linkText }) => {
  const [showParentContainer, setShowParentContainer] = useState(false);
  const [parentItems, setParentItems] = useState([]);
  const [activeParentId, setActiveParentId] = useState(null);
  const [childItems, setChildItems] = useState([]);

  const fetchDataFromAPI = async () => {
    try {
      const response = await axios.get('http://example.com/api/get-menu-options.php');
      const data = response.data;
      setParentItems(data.filter(item => item.parent_id === null));
      setChildItems(data.filter(item => item.parent_id !== null));
    } catch (error) {
      console.error('Error fetching data: ', error);
    }
  };

  useEffect(() => {
    fetchDataFromAPI();
  }, []);

  const handleLinkHover = () => {
    setShowParentContainer(true);
    setActiveParentId(null);
  };

  const handleParentItemHover = (parentId) => {
    setShowParentContainer(true);
    setActiveParentId(parentId);
  };

  const handleChildItemHover = () => {
    setShowParentContainer(false);
  };

  const filteredChildItems = childItems.filter(item => item.parent_id === activeParentId);
  const hasChildItems = filteredChildItems.length > 0;
  return (
    <div id='demo-content' className='phppot-container'>
    <div className='textline'>
      <div className='hoverlink'
        onMouseEnter={handleLinkHover}
        onMouseLeave={() => setShowParentContainer(false)}
      >
        <a>
          {linkText}
        </a>
      
        {showParentContainer && (
         <div className='parent-container'>
         {parentItems.map(parentItem => {
           const hasChildren = childItems.some(childItem => childItem.parent_id === parentItem.id);
       
           return (
             <div
               key={parentItem.id}
               onMouseEnter={() => handleParentItemHover(parentItem.id)}
               className={parentItem.id === activeParentId ? 'parent-item active' : 'parent-item'}
             >
               <p>
                 {parentItem.name}
                 {hasChildren && <span className='triangle-arrow'>&#9656;</span>}
               </p>
             </div>
           );
         })}
       </div>
       
       
        )}
        {showParentContainer && activeParentId !== null && hasChildItems && (
          <div className='child-container'
            onMouseLeave={handleChildItemHover}
          >
            <div>
              {filteredChildItems.map(childItem => (
                <div key={childItem.id}>
                  <p>{childItem.name}</p>
                </div>
              ))}
            </div>
          </div>
        )}
      </div>
      <a href='#'>Products</a>
          <a href='#'>Other Offers</a>
          <a href='#'>Contact</a>
    </div>
    </div>
  );
};

export default Dropdown;